Re: [PATCH v4 2/4] t3427: accelerate this test by using fast-export and fast-import
- From
Johannes Schindelin <johannes.schindelin@gmx.de>
- Date
- Sep 2, 2019, 14:45 UTC
- Message-ID
- <nycvar.QRO.7.76.6.1909021641490.46@tvgsbejvaqbjf.bet>
- In-Reply-To
- <20190830055707.7785-3-newren@gmail.com>
Hi Elijah,
On Thu, 29 Aug 2019, Elijah Newren wrote:
Show 9 quoted lines
> fast-export and fast-import can easily handle the simple rewrite that > was being done by filter-branch, and should be significantly faster on > systems with a slow fork. Timings from before and after on two laptops > that I have access to (measured via `time ./t3427-rebase-subtree.sh`, > i.e. including everything in this test -- not just the filter-branch or > fast-export/fast-import pair): > > Linux: 4.305s -> 3.684s (~17% speedup) > Mac: 10.128s -> 7.038s (~30% speedup)
This patch seems to accelerate t3427 on my Windows laptop, too, from ~1m37s to ~1m17s, i.e. ~20%.
Ciao, Dscho